# Cấu hình

## Tham số runtime

- `host`
- `port`
- `workers`

## Biến môi trường

- `VYRO_ENV`
- `VYRO_SECRET_KEY`
- `VYRO_WORKERS`
- `VYRO_LOG_SAMPLE_INFO`
- `VYRO_LOG_SAMPLE_WARN`
- `VYRO_LOG_SAMPLE_ERROR`

Dùng `vyro doctor --strict` trong CI để kiểm tra production readiness.
